==> nextcloud-27.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/text/l10n/es_CL.js <==
OC.L10N.register(
    "text",
    {
    "New text file" : "Nuevo archivo de texto",
    "The file was uploaded" : "El archivo fue cargado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
    "The file was only partially uploaded" : "El archivo sólo fue cargado parcialmente",
    "No file was uploaded" : "No se cargó el archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No fue posible escribir a disco",
    "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
    "Text" : "Texto",
    "Guest" : "Invitado",
    "Offline" : "Sin conexión",
    "Saved" : "Guardado",
    "Unsaved changes" : "Cambios no guardados",
    "Formatting help" : "Ayuda de formato",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Translate" : "Traducir",
    "Select language" : "Selecciona el idioma",
    "to" : "para",
    "Replace" : "Reemplazar",
    "Source code" : "Código fuente",
    "Unsupported image type" : "Tipo de imagen no soportado",
    "Undo" : "Deshacer",
    "Info" : "Info",
    "Success" : "Éxito",
    "Warning" : "Advertencia",
    "Edit" : "Editar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/text/l10n/es_CL.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "El archivo fue cargado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
    "The file was only partially uploaded" : "El archivo sólo fue cargado parcialmente",
    "No file was uploaded" : "No se cargó el archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No fue posible escribir a disco",
    "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
    "New text file" : "Nuevo archivo de texto",
    "File not found" : "Archivo no encontrado",
    "Text" : "Texto",
    "Guest" : "Invitado",
    "you" : "tú",
    "Copy link" : "Copiar liga",
    "Offline" : "Sin conexión",
    "Saved" : "Guardado",
    "Unsaved changes" : "Cambios no guardados",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Link" : "Ligas",
    "name" : "nombre",
    "Action" : "Acción",
    "Undo" : "Deshacer",
    "Cancel" : "Cancel",
    "URL" : "URL",
    "Save" : "Guardar",
    "Formatting help" : "Ayuda de formato",
    "Translate" : "Traducir",
    "Select language" : "Selecciona el idioma",
    "to" : "para",
    "Replace" : "Reemplazar",
    "Edit" : "Editar",
    "Upload" : "Cargar",
    "Source code" : "Código fuente",
    "Choose" : "Seleccionar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
